@@ -42,6 +42,8 @@ class DeviceInformation:
         modelNumber = deviceInfo["modelNumber"]
         serialNumber = deviceInfo["serialNumber"]
         versionNumber = deviceInfo["versionNumber"]
+        bouquet = deviceInfo["bouquet"]
+        subbouquet = deviceInfo["subbouquet"]
 
         epgCountryCode = overrideCountry or countryCode.upper()
         if not epgCountryCode:
@@ -62,6 +64,8 @@ class DeviceInformation:
             modelNumber,
             serialNumber,
             versionNumber,
+            bouquet,
+            subbouquet,
         )
 
     def getSoapControlURL(self):
@@ -129,6 +133,16 @@ class Device:
         repr=True,
         compare=False,
     )
+    bouquet: str = field(
+        init=True,
+        repr=True,
+        compare=False,
+    )
+    subbouquet: str = field(
+        init=True,
+        repr=True,
+        compare=False,
+    )
 
     def as_json(self) -> str:
         """Return a JSON string representing this device info."""
