@@ -14,21 +14,11 @@ from .classes.favourite import FavouriteInformation
 from .classes.media import MediaInformation
 from .classes.programme import Programme
 from .classes.recordings import RecordingsInformation
-from .const import (
-    ALLRECORDINGS,
-    COMMANDS,
-    CURRENT_TRANSPORT_STATE,
-    EPG_ERROR_NO_DATA,
-    EPG_ERROR_PAST_END,
-    SKY_STATE_NOMEDIA,
-    SKY_STATE_OFF,
-    SKY_STATE_ON,
-    SKY_STATE_PAUSED,
-    SKY_STATE_PLAYING,
-    SKY_STATE_STANDBY,
-    SKY_STATE_STOPPED,
-    SKY_STATE_TRANSITIONING,
-)
+from .const import (ALLRECORDINGS, COMMANDS, CURRENT_TRANSPORT_STATE,
+                    EPG_ERROR_NO_DATA, EPG_ERROR_PAST_END, SKY_STATE_NOMEDIA,
+                    SKY_STATE_OFF, SKY_STATE_ON, SKY_STATE_PAUSED,
+                    SKY_STATE_PLAYING, SKY_STATE_STANDBY, SKY_STATE_STOPPED,
+                    SKY_STATE_TRANSITIONING)
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -44,7 +34,6 @@ class SkyQRemote:
         self._host = host
         self._remoteCountry = None
         self._overrideCountry = None
-        self._epgCountryCode = None
         self._channel = None
         self._programme = None
         self._recordedProgramme = None
@@ -275,7 +264,7 @@ class SkyQRemote:
             self._deviceInformation = DeviceInformation(self._remoteConfig)
 
         deviceInfo = self._deviceInformation.getDeviceInformation(self._overrideCountry)
-        self._epgCountryCode = deviceInfo.epgCountryCode
+        self._remoteConfig.deviceInfo = deviceInfo
         return deviceInfo
 
     def getChannelList(self):
@@ -288,7 +277,7 @@ class SkyQRemote:
 
     def getChannelInfo(self, channelNo):
         """Retrieve channel information for specified channelNo."""
-        if not self._channelInformation:
+        if not self._channelInformation or not self._channelInformation.remoteCountry:
             self._channelInformation = ChannelInformation(self._remoteConfig)
 
         return self._channelInformation.getChannelInfo(channelNo)
@@ -326,7 +315,7 @@ class SkyQRemote:
             self._setupDevice()
 
         if not self._remoteCountry and self.deviceSetup:
-            SkyQCountry = self._importCountry(self._epgCountryCode)
+            SkyQCountry = self._importCountry(self._remoteConfig.deviceInfo.epgCountryCode)
             self._remoteCountry = SkyQCountry()
             self._remoteConfig.remoteCountry = self._remoteCountry
 
@@ -360,6 +349,7 @@ class _RemoteConfig:
     test_channel = 0
     soapControlURL = ""
     epgCacheLen = 0
+    deviceInfo = None
 
     def __init__(
         self,
@@ -371,6 +361,7 @@ class _RemoteConfig:
         remoteCountry=None,
         test_channel=None,
         soapControlURL=None,
+        deviceInfo=None,
     ):
         self.host = host
         self.port = port
@@ -381,3 +372,4 @@ class _RemoteConfig:
         self.soapControlURL = soapControlURL
         self.epgCacheLen = epgCacheLen
         self.deviceAccess = DeviceAccess(host, jsonPort, port)
+        self.deviceInfo = deviceInfo
